---
title: GitHub Codespaces
parent: Installation
nav_order: 900
---

# GitHub Codespaces

You can use aider in GitHub Codespaces via the built-in Terminal pane.
See below for an example,
but you can see the 
[main install instructions](/docs/install.html)
for all the details.


<div class="video-container">
  <video controls poster="/assets/codespaces.jpg">
    <source src="/assets/codespaces.mp4" type="video/mp4">
    <a href="/assets/codespaces.mp4">Install aider in GitHub Codespaces</a>
  </video>
</div>

<style>
.video-container {
  position: relative;
  padding-bottom: 101.89%; /* 1080 / 1060 = 1.0189 */
  height: 0;
  overflow: hidden;
}

.video-container video {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
</style>

